@@ -17,13 +17,15 @@ class ExposedResource(BaseResource):
         kwargs = {}
         for key in request.args:
             kwargs[key] = request.args[key][0]
-        try:
-            d = self.interfaceserver.createReservation(self.function_name, **kwargs)
-        except:
-            return self._errorResponse(
-                Failure(exc_value=sys.exc_value, 
-                    exc_type=sys.exc_type, 
-                    exc_tb=sys.exc_traceback))
+        
+        d = self.interfaceserver.createReservation(self.function_name, **kwargs)
+        #try:
+        #    d = self.interfaceserver.createReservation(self.function_name, **kwargs)
+        #except:
+        #    return self._errorResponse(
+        #        Failure(exc_value=sys.exc_value, 
+        #            exc_type=sys.exc_type, 
+        #            exc_tb=sys.exc_traceback))
         d.addCallback(self._successResponse)
         d.addErrback(self._errorResponse)
         d.addCallback(self._immediateResponse, request)
