@@ -34,7 +34,9 @@ class InterfaceServer(BaseServer):
             time_offset=None):
         if name == None:
             name = "AWSpider Interface Server UUID: %s" % self.uuid
-        resource = InterfaceResource(self)
+        resource = Resource()
+        interface_resource = InterfaceResource(self)
+        resource.putChild("interface", interface_resource)
         self.function_resource = Resource()
         resource.putChild("function", self.function_resource)
         self.site_port = reactor.listenTCP(port, server.Site(resource))
@@ -183,3 +185,7 @@ class InterfaceServer(BaseServer):
     def _createReservationErrback2( self, error, function_name, uuid ):
         LOGGER.error( "Unable to create reservation for %s:%s, %s.\n" % (function_name, uuid, error) )
         return error
+    
+    def showReservation(self, uuid):
+        d = self.sdb.getAttributes(self.aws_sdb_reservation_domain, uuid)
+        return d
